@@ -18,6 +18,7 @@
 #include <stdio.h>
 #include <unistd.h>
 #include <string.h>
+#include <glib.h>
 #include <glib-object.h>
 
 #include <bonobo/bonobo-widget.h>
@@ -362,7 +363,7 @@ info_free_fn (BonoboUIXmlData *data)
 	NodeInfo *info = (NodeInfo *) data;
 
 	if (info->object != CORBA_OBJECT_NIL) {
-		dprintf ("** Releasing object %p on info %p\n", info->object, info);
+		dbgprintf ("** Releasing object %p on info %p\n", info->object, info);
 		bonobo_object_release_unref (info->object, NULL);
 		info->object = CORBA_OBJECT_NIL;
 	}
@@ -1175,7 +1176,7 @@ bonobo_ui_engine_object_set (BonoboUIEngine   *engine,
 		widget_unref (&info->widget);
 	}
 	
-	dprintf ("** Setting object %p on info %p\n", object, info);
+	dbgprintf ("** Setting object %p on info %p\n", object, info);
 	info->object = bonobo_object_dup_ref (object, ev);
 
 	bonobo_ui_xml_set_dirty (engine->priv->tree, node);
@@ -1217,8 +1218,7 @@ bonobo_ui_engine_widget_set (BonoboUIEngine    *engine,
 
 	if (custom_widget) {
 		info = bonobo_ui_xml_get_data (engine->priv->tree, node);
-		info->widget = gtk_widget_ref (custom_widget);
-		gtk_object_sink (GTK_OBJECT (custom_widget));
+		info->widget = g_object_ref_sink (custom_widget);
 
 		bonobo_ui_engine_stamp_custom (engine, node);
 	}
@@ -1850,7 +1850,7 @@ bonobo_ui_engine_dispose (BonoboUIEngine *engine)
 	GSList *l;
 	BonoboUIEnginePrivate *priv = engine->priv;
 
-	dprintf ("bonobo_ui_engine_dispose %p\n", engine);
+	dbgprintf ("bonobo_ui_engine_dispose %p\n", engine);
 
 	bonobo_ui_engine_freeze (engine);
 
@@ -1899,7 +1899,7 @@ impl_finalize (GObject *object)
 {
 	BonoboUIEngine *engine;
 
-	dprintf ("bonobo_ui_engine_finalize %p\n", object);
+	dbgprintf ("bonobo_ui_engine_finalize %p\n", object);
        
 	engine = BONOBO_UI_ENGINE (object);
 
@@ -2321,10 +2321,10 @@ bonobo_ui_engine_sync (BonoboUIEngine   *engine,
 				} else {
 					g_warning ("non dirty node, but widget mismatch "
 						   "a: '%s:%s', b: '%s:%s' '%p'",
-						   bonobo_ui_node_get_name (a),
-						   bonobo_ui_node_peek_attr (a, "name"),
-						   bn ? bonobo_ui_node_get_name (bn) : "NULL",
-						   bn ? bonobo_ui_node_peek_attr (bn, "name") : "NULL",
+						   bonobo_ui_node_get_name (a) ? bonobo_ui_node_get_name (a) : "NULL",
+						   bonobo_ui_node_peek_attr (a, "name") ? bonobo_ui_node_peek_attr (a, "name") : "NULL",
+						   bn ? (bonobo_ui_node_get_name (bn) ? bonobo_ui_node_get_name (bn) : "NULL") : "NULL",
+						   bn ? (bonobo_ui_node_peek_attr (bn, "name") ? bonobo_ui_node_peek_attr (bn, "name") : "NULL" ) : "NULL",
 						   info->widget);
 				}
 			}
@@ -2372,7 +2372,7 @@ check_excess_widgets (BonoboUISync *sync, GList *wptr)
 
 			node = bonobo_ui_engine_widget_get_node (b->data);
 			g_message ("Widget type '%s' with node: '%s'",
-				   G_OBJECT_CLASS_NAME (b->data),
+				   G_OBJECT_CLASS_NAME (G_OBJECT_GET_CLASS (b->data)) ? G_OBJECT_CLASS_NAME (G_OBJECT_GET_CLASS (b->data)) : "NULL",
 				   node ? bonobo_ui_xml_make_path (node) : "NULL");
 		}
 	}
@@ -3158,7 +3158,7 @@ bonobo_ui_engine_thaw (BonoboUIEngine *engine)
  * 
  * This is a debugging function mostly for internal
  * and testing use, it dumps the XML tree, including
- * the assoicated, and overridden nodes in a wierd
+ * the associated, and overridden nodes in a wierd
  * hackish format to the @out stream with the
  * helpful @msg prepended.
  **/
